@@ -95,7 +95,7 @@ class InlineClosureCallPass(object):
         modified = False
         work_list = list(self.func_ir.blocks.items())
         debug_print = _make_debug_print("InlineClosureCallPass")
-        debug_print("START")
+        debug_print(f"START {self.func_ir.func_id.func_qualname}")
         while work_list:
             _label, block = work_list.pop()
             for i, instr in enumerate(block.body):
